@@ -64,6 +64,7 @@ weather_initialize_dbus(void) {
 
 #ifdef USE_CONIC
         app->connection = con_ic_connection_new();
+
         if (app->connection != NULL) {
             g_object_set(app->connection, "automatic-connection-events",
                          TRUE, NULL);
@@ -72,6 +73,7 @@ weather_initialize_dbus(void) {
                              G_CALLBACK(connection_cb),
                              GINT_TO_POINTER(USER_DATA_MAGIC));
         }
+
 #else
     #ifndef NONMAEMO
         osso_iap_cb(iap_callback);
@@ -135,6 +137,12 @@ weather_deinitialize_dbus(void) {
     START_FUNCTION;
 #endif
 
+#ifdef USE_CONIC
+  if (app->connection){
+      g_object_unref(app->connection);
+  }
+#endif
+
     if (app->dbus_conn){
 #if !defined OS2008 && !defined OS2009 && !defined NONMAEMO
          dbus_bus_remove_match(app->dbus_conn, ICD_DBUS_INTERFACE, NULL);
